@@ -4,4 +4,5 @@ from .SchemaType import SchemaType
 from .SchemaPrimitive import SchemaPrimitive
 from .SchemaNone import SchemaNone
 from .SchemaConst import SchemaConst
-
+from .SchemaEnum import SchemaEnum
+from .SchemaPattern import SchemaPattern
