@@ -7,6 +7,15 @@ from .resolve_arg_to_type import resolve_arg_to_schema
 
 
 class SchemaArray(Schema):
+    """
+    A schema specifying an array (corresponding to a Python list)
+
+    :param items: The permitted data type or schema for the items of this array. Must
+                  be one of:
+                  A primitive Python type (str, int, bool, float)
+                  A subclass of `UserObject`
+                  An instance of `Schema`
+    """
 
     items: Schema = None
 
@@ -24,13 +33,17 @@ class SchemaArray(Schema):
         return DOMList(
             value,
             dom_info,
-            _item_type=self.items
+            item_type=self.items
         )
 
     @property
-    def schema(self) -> Dict[str, Any]:
+    def referenced_schemas(self) -> Dict[str, Schema]:
+        return self.items.referenced_schemas
+
+    @property
+    def jsonschema_definition(self) -> Dict[str, Any]:
         return {
             "array": {
-                "items": self.items
+                "items": self.items.jsonschema_ref_schema
             }
         }
